@@ -87,7 +87,7 @@ class ABSStore(Store):
                 "https://{}.blob.core.windows.net/".format(account_name),
                 container,
                 credential=account_key,
-                **blob_service_kwargs
+                **blob_service_kwargs,
             )
 
         self.client = client
@@ -240,7 +240,6 @@ class ABSStoreV3(ABSStore, StoreV3):
         super().__setitem__(key, value)
 
     def rmdir(self, path=None):
-
         if not path:
             # Currently allowing clear to delete everything as in v2
 
