@@ -145,7 +145,7 @@ class Group(MutableMapping):
         synchronizer=None,
         zarr_version=None,
         *,
-        meta_array=None
+        meta_array=None,
     ):
         store: BaseStore = _normalize_store_arg(store, zarr_version=zarr_version)
         if zarr_version is None:
@@ -919,7 +919,6 @@ class Group(MutableMapping):
         return TreeViewer(self, expand=expand, level=level)
 
     def _write_op(self, f, *args, **kwargs):
-
         # guard condition
         if self._read_only:
             raise ReadOnlyError()
@@ -1094,7 +1093,6 @@ class Group(MutableMapping):
         return self._write_op(self._create_dataset_nosync, name, **kwargs)
 
     def _create_dataset_nosync(self, name, data=None, **kwargs):
-
         assert "mode" not in kwargs
         path = self._item_path(name)
 
@@ -1138,11 +1136,9 @@ class Group(MutableMapping):
         )
 
     def _require_dataset_nosync(self, name, shape, dtype=None, exact=False, **kwargs):
-
         path = self._item_path(name)
 
         if contains_array(self._store, path):
-
             # array already exists at path, validate that it is the right shape and type
 
             synchronizer = kwargs.get("synchronizer", self._synchronizer)
@@ -1235,7 +1231,7 @@ class Group(MutableMapping):
             path=path,
             chunk_store=self._chunk_store,
             fill_value=fill_value,
-            **kwargs
+            **kwargs,
         )
 
     def array(self, name, data, **kwargs):
@@ -1360,7 +1356,8 @@ def group(
     synchronizer=None,
     path=None,
     *,
-    zarr_version=None
+    zarr_version=None,
+    meta_array=None,
 ):
     """Create a group.
 
@@ -1382,6 +1379,11 @@ def group(
         Array synchronizer.
     path : string, optional
         Group path within store.
+    meta_array : array-like, optional
+        An array instance to use for determining arrays to create and return
+        to users. Use `numpy.empty(())` by default.
+
+        .. versionadded:: 2.16.1
 
     Returns
     -------
@@ -1432,6 +1434,7 @@ def group(
         synchronizer=synchronizer,
         path=path,
         zarr_version=zarr_version,
+        meta_array=meta_array,
     )
 
 
@@ -1445,7 +1448,7 @@ def open_group(
     storage_options=None,
     *,
     zarr_version=None,
-    meta_array=None
+    meta_array=None,
 ):
     """Open a group using file-mode-like semantics.
 
