@@ -1,11 +1,17 @@
 import os
 from collections import defaultdict
 from threading import Lock
-
-import fasteners
+from typing import Protocol
 
 
-class ThreadSynchronizer:
+class Synchronizer(Protocol):
+    """Base class for synchronizers."""
+
+    def __getitem__(self, item):
+        ...
+
+
+class ThreadSynchronizer(Synchronizer):
     """Provides synchronization using thread locks."""
 
     def __init__(self):
@@ -24,7 +30,7 @@ class ThreadSynchronizer:
         self.__init__()
 
 
-class ProcessSynchronizer:
+class ProcessSynchronizer(Synchronizer):
     """Provides synchronization using file locks via the
     `fasteners <https://fasteners.readthedocs.io/en/latest/api/inter_process/>`_
     package.
@@ -41,6 +47,8 @@ class ProcessSynchronizer:
         self.path = path
 
     def __getitem__(self, item):
+        import fasteners
+
         path = os.path.join(self.path, item)
         lock = fasteners.InterProcessLock(path)
         return lock
